@@ -4,7 +4,7 @@
 #' with subjects in mode 1, features in mode 2 and time in mode 3.
 #'
 #' @format ## 'Cornejo2025'
-#' A list object with three elements:
+#' A list object with seven elements:
 #' \describe{
 #'     \item{Tongue_microbiome}{List object of the tongue longitudinal microbiota data.}
 #'     \item{Salivary_microbiome}{List object of the saliva longitudinal microbiota data.}
@@ -16,3 +16,18 @@
 #' }
 #' @source TBD
 "Cornejo2025"
+
+#' Jakobsen2025 longitudinal dataset measured in mother-infant dyads
+#'
+#' The Jakobsen2025 longitudinal dataset as three-dimensional arrays,
+#' with subjects in mode 1, features in mode 2 and time in mode 3.
+#'
+#' @format ## 'Jakobsen2025'
+#' A list object with three elements:
+#' \describe{
+#'     \item{faeces}{List object of the longitudinal infant faecal microbiota data.}
+#'     \item{milkMicrobiome}{List object of the longitudinal HM microbiota data.}
+#'     \item{milkMetabolomics}{List object of the longitudinal salivary cytokine data.}
+#' }
+#' @source TBD
+"Jakobsen2025"
